# autogenerated module
from typing import ClassVar

from ..core import resource as res
from ..models import networking_v1 as m_networking_v1


class NetworkPolicy(res.NamespacedResourceG, m_networking_v1.NetworkPolicy):
    """* **Extends**: ``models.networking_v1.NetworkPolicy``
       * **Type**: Namespaced Resource
       * **Accepted client methods**: `delete`, `deletecollection`, `get`, `list` all, `watch` all, `list`, `patch`, `create`, `replace`, `watch`
    """
    _api_info = res.ApiInfo(
        resource=res.ResourceDef('networking.k8s.io', 'v1', 'NetworkPolicy'),
        plural='networkpolicies',
        verbs=['delete', 'deletecollection', 'get', 'global_list', 'global_watch', 'list', 'patch', 'post', 'put', 'watch'],
    )

